#include <gnome.h>


void
on_Dvd95_destroy                       (GtkObject       *object,
                                        gpointer         user_data);

void
on_proprietes_clicked                  (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_ViewPiste_clicked                   (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_Encoder_clicked                     (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

gboolean
on_PistesVideo_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_PistesAudio_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_SousTitres_button_press_event       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_SousTitres_button_release_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_cfgsave_clicked                     (GtkObject       *object,
                                        gpointer         user_data);

void
on_cfgiso_destroy                      (GtkObject       *object,
                                        gpointer         user_data);

void
on_propriete_destroy                   (GtkObject       *object,
                                        gpointer         user_data);

void
on_choixiso_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_PistesVideo_button_release_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_PistesAudio_button_release_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_avCancel_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_Pause_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_Evaluer_clicked                     (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_quitter_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_rafraichir_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_lecture_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_revenir_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_avancer_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_arreter_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_fermer_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_alerte_deuxiemephase_destroy        (GtkObject       *object,
                                        gpointer         user_data);

void
on_cfgdev_changed                      (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_cfgvisu_changed                     (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_About_clicked                       (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

gboolean
on_Dvd95_delete                        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_visumpeg_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_rescan_clicked                      (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_configbegin_clicked                 (GtkButton       *button,
                                        gpointer         user_data);
